package de.tudresden.inf.st.mquat.eris;

import de.tudresden.inf.st.mquat.benchmark.SolverFactory;
import de.tudresden.inf.st.mquat.eris.coupling.ERISConnector;
import de.tudresden.inf.st.mquat.jastadd.model.MquatWriteSettings;
import de.tudresden.inf.st.mquat.jastadd.model.Root;
import de.tudresden.inf.st.mquat.jastadd.model.Solution;
import de.tudresden.inf.st.mquat.solving.SolvingException;
import de.tudresden.inf.st.mquat.solving.ilp.ILPExternalSolver;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.util.TimerTask;

public class ErisTask extends TimerTask {

  private static final Logger logger = LogManager.getLogger(ErisTask.class);

  public void run() {
    long currentTime = System.nanoTime();
    try {
      ERISConnector erisConnector = new ERISConnector();
      erisConnector.read();
      Root model = ErisMQuATBuilder.createModel(erisConnector.getErisModel());

//      System.out.println(model.print(new MquatWriteSettings("  ")));

      ILPExternalSolver solver = (ILPExternalSolver) SolverFactory.getSolverByName("ilp-glpk");

      Solution solution = solver.solve(model);

//      System.out.println(solution.print(new MquatWriteSettings("  ")));

      if (solution.getNumAssignment() > 0) {
        logger.info("Found solution. Sending now...");
        erisConnector.write(solution);
      } else {
        logger.warn("Not sending empty solution!");
      }

    } catch (SolvingException e) {
      logger.error("Solving the contract failed: {}", e.getMessage());
    } catch (Exception e) {
      logger.error("MQuAT failed:");
      e.printStackTrace();
    }
    logger.info("The previous run of MQuAT took {}s", (System.nanoTime() - currentTime) / 1000000000.0D);

  }
}
