package de.tudresden.inf.st.mquat.eris.coupling;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

public class ERISAccessPath {
  private String addressingMode;
  private boolean dynamic;
  private int id;
  private String name;
  private List<ERISBenchmarkResult> resultList = new ArrayList<>();

  //properties
  private String attributeCount;
  private int attributeNull;
  private int attributeUndefined;
  private int dynamicAttributeSize;
  private int indexAttributeCount;
  private int indexOrderPreserving;

  public ERISAccessPath(JSONObject jsonObject) {
    addressingMode = jsonObject.getString("addressingMode");
    dynamic = jsonObject.getBoolean("dynamic");
    id = jsonObject.getInt("id");
    name = jsonObject.getString("name");

    JSONArray performances = jsonObject.getJSONArray("performances");
    for (int i = 0; i < performances.length(); i++) {
      resultList.add(new ERISBenchmarkResult(performances.getJSONObject(i)));
    }

    JSONObject properties = jsonObject.getJSONObject("properties");
    attributeCount = properties.get("attributeCount").toString();
    attributeNull = properties.getInt("attributeNull");
    attributeUndefined = properties.getInt("attributeUndefined");
    dynamicAttributeSize = properties.getInt("dynamicAttributeSize");
    indexAttributeCount = properties.getInt("indexAttributeCount");
    indexOrderPreserving = properties.getInt("indexOrderPreserving");
  }

  public String getAddressingMode() {
    return addressingMode;
  }

  public void setAddressingMode(String addressingMode) {
    this.addressingMode = addressingMode;
  }

  public boolean isDynamic() {
    return dynamic;
  }

  public void setDynamic(boolean dynamic) {
    this.dynamic = dynamic;
  }

  public int getId() {
    return id;
  }

  public void setId(int id) {
    this.id = id;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public List<ERISBenchmarkResult> getResultList() {
    return resultList;
  }

  public void setResultList(List<ERISBenchmarkResult> resultList) {
    this.resultList = resultList;
  }

  public String getAttributeCount() {
    return attributeCount;
  }

  public void setAttributeCount(String attributeCount) {
    this.attributeCount = attributeCount;
  }

  public int getAttributeNull() {
    return attributeNull;
  }

  public void setAttributeNull(int attributeNull) {
    this.attributeNull = attributeNull;
  }

  public int getAttributeUndefined() {
    return attributeUndefined;
  }

  public void setAttributeUndefined(int attributeUndefined) {
    this.attributeUndefined = attributeUndefined;
  }

  public int getDynamicAttributeSize() {
    return dynamicAttributeSize;
  }

  public void setDynamicAttributeSize(int dynamicAttributeSize) {
    this.dynamicAttributeSize = dynamicAttributeSize;
  }

  public int getIndexAttributeCount() {
    return indexAttributeCount;
  }

  public void setIndexAttributeCount(int indexAttributeCount) {
    this.indexAttributeCount = indexAttributeCount;
  }

  public int getIndexOrderPreserving() {
    return indexOrderPreserving;
  }

  public void setIndexOrderPreserving(int indexOrderPreserving) {
    this.indexOrderPreserving = indexOrderPreserving;
  }

  public double getLookupTime(int att_count) {
    // get the correct size
    double lookuptime = 0;
    int dist = Integer.MAX_VALUE;
    for (ERISBenchmarkResult i : resultList) {
      if (Math.abs(att_count - i.getDataSize()) < dist) {
        dist = Math.abs(att_count - i.getDataSize());
        lookuptime = i.getLookup();
      }
    }

    return lookuptime;
  }

  public String getUId() {
    return getId() + "_" + getAddressingMode();
  }

  @Override
  public String toString() {
    return "(AP " + getId() + ": " + getName() + " (" + getAddressingMode() + "))";
  }

}
