package de.tudresden.inf.st.mquat.eris.coupling;

import org.json.JSONObject;

import java.util.*;

public class ERISContainer {
    //general info
    private int id;
    private boolean initialized;
    private boolean mvcc;
    private String type;

    //content
    private Map<Integer, ERISAttribute> attributes = new HashMap<>();
    private Map<String, ERISLivingPartition> partitions = new HashMap<>();

    // parent
    private ERISModel model;

    public ERISContainer(JSONObject jsonObject, ERISModel model){
        id = Integer.parseInt(jsonObject.get("id").toString());
        initialized = Boolean.parseBoolean(jsonObject.get("initialized").toString());
        mvcc = Boolean.parseBoolean(jsonObject.get("mvcc").toString());
        type = jsonObject.get("type").toString();
        this.model = model;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    public boolean isInitialized() {
        return initialized;
    }

    public boolean isMvcc() {
        return mvcc;
    }

    public String getType() {
        return type;
    }

    public Collection<ERISAttribute> getAttributes() {
        return attributes.values();
    }

    public void addAttribute(ERISAttribute attribute) {
        attributes.put(attribute.getId(), attribute);
    }

    public ERISAttribute getAttribute(int id) {
        return attributes.get(id);
    }

    public void addPartititon(ERISLivingPartition partition) {
        partitions.put(partition.getGlobalId(), partition);
    }

    public ERISLivingPartition getPartition(int nodeId, int id) {
        return partitions.get(nodeId + "_" + id);
    }

    public ERISLivingPartition getPartition(String globalId) {
        return partitions.get(globalId);
    }

    public Collection<ERISLivingPartition> getPartitions() {
        return partitions.values();
    }

    public void addPartition(ERISLivingPartition partition) {
        partitions.put(partition.getGlobalId(), partition);
    }

    public ERISModel getModel() {
        return model;
    }

    @Override
    public String toString() {
        return String.valueOf(getId());
    }

}
