package de.tudresden.inf.st.mquat.eris.coupling;

import org.json.JSONObject;

import java.util.*;

public class ERISLivingPartition {
    //general info
    private boolean adaptationScheduled;
    private int localId;
    private int nodeId;
    private boolean ignore;

    //content
    private List<ERISLPConfiguration> configurations = new ArrayList<>();
    private ERISLPStatistics statistics;
    private Map<ERISAttribute, ERISAttributeStatistics> attributeList = new HashMap<>();

    // parent
    private ERISContainer container;

    public ERISLivingPartition(JSONObject jsonObject, ERISContainer container){
        adaptationScheduled = jsonObject.getBoolean("adaptationScheduled");
        localId = jsonObject.getInt("localId");
        nodeId = jsonObject.getInt("node");
        this.container = container;
    }

    public void setIgnore(boolean ignore) {
        this.ignore = ignore;
    }

    public boolean isIgnore() {
        return ignore;
    }

    public boolean isAdaptationScheduled() {
        return adaptationScheduled;
    }

    public int getLocalId() {
        return localId;
    }

    public int getNodeId() {
        return nodeId;
    }

    public String getGlobalId() {
        return nodeId + "_" + localId;
    }

    public ERISContainer getContainer() {
        return container;
    }

    public List<ERISLPConfiguration> getConfigurations() {
        return configurations;
    }

    public void setConfigurations(List<ERISLPConfiguration> configurations) {
        this.configurations = configurations;
    }

    public ERISLPStatistics getStatistics() {
        return statistics;
    }

    public void setStatistics(ERISLPStatistics statistics) {
        this.statistics = statistics;
    }

    public ERISAttributeStatistics getAttributeStatistics(ERISAttribute attribute) {
        return attributeList.get(attribute);
    }

    public void addAttributeStatistics(ERISAttributeStatistics statistics) {
        this.attributeList.put(statistics.getAttribute(), statistics);
    }

    public Optional<ERISLPConfiguration> getConfigForAttribute(ERISAttribute attribute, boolean index) {
        if (this.configurations == null) {
            return Optional.empty();
        }
        for (ERISLPConfiguration config : this.configurations) {
            if (config == null || config.getAttributesAndKeys() == null || config.getAccessPath() == null || config.getAccessPath().getAddressingMode() == null) {
                continue;
            }
            if (config.getAttributesAndKeys().contains(attribute) && config.getAccessPath().getAddressingMode().equals("index") == index) {
                return Optional.of(config);
            }
        }
        return Optional.empty();
    }

    @Override
    public String toString() {
        return String.valueOf(getGlobalId());
    }
}
